pub struct SubBlock {
pub version: SubBlockVersion,
pub parent_hash: B256,
pub fee_recipient: Address,
pub transactions: Vec<TempoTxEnvelope>,
}Fields
version: SubBlockVersionVersion of the subblock.
parent_hash: B256Hash of the parent block. This subblock can only be included as part of the block building on top of the specified parent.
fee_recipient: AddressRecipient of the fees for the subblock.
transactions: Vec<TempoTxEnvelope>Transactions included in the subblock.
Implementations
Sourceimpl SubBlock
impl SubBlock
Sourcepub fn signature_hash(&self) -> B256
pub fn signature_hash(&self) -> B256
Returns the hash for the signature.
Sourcepub fn total_tx_size(&self) -> usize
pub fn total_tx_size(&self) -> usize
Returns the total length of the transactions in the subblock.